# BloodHound customqueries merge description

Place in this directory your valid *.json BloodHound customqueries files.
When initializing a container, they will be `merged` altogether with Exegol's at `~/.config/bloodhound/customqueries.json`.